﻿param($installPath, $toolsPath, $package, $project)

Import-Module (Join-Path $toolsPath "Get-ConfigPath.psm1")
Import-Module (Join-Path $toolsPath "Get-Config.psm1")
Import-Module (Join-Path $toolsPath "Update-AssemblyBinding.psm1")

Function UpdateMediachaseSearchConfig($configPath)
{
    $config = Get-Config $configPath

    $providers = $config.SelectSingleNode("/Mediachase.Search/SearchProviders/providers")

    $element = $config.SelectSingleNode("/Mediachase.Search/SearchProviders/providers/add[@name='SolrSearchProvider']")
    if ($element -eq $null)
    {
        $element = $config.CreateElement("add", $null)
        $providers.AppendChild($element) | Out-Null
		
		$element.SetAttribute('name','SolrSearchProvider')
		$element.SetAttribute('type','Mediachase.Search.Providers.Solr.SolrSearchProvider, Mediachase.Search.SolrSearchProvider')
		$element.SetAttribute('queryBuilderType','Mediachase.Search.Providers.Solr.SolrSearchQueryBuilder, Mediachase.Search.SolrSearchProvider')
		$element.SetAttribute('url','http://localhost:8080/solr')   
		$element.SetAttribute('shareCores','true')    
    }
    
	$config.Save($configPath)
}

#add/update binding redirects for assemblies in the current package
$configPath = Get-ConfigPath $project
if ($configPath -eq $null)
{
	Write-Host "Unable to find a configuration file, binding redirect not configured."
}
else
{
	$config = Get-Config $configPath
	Update-AssemblyBinding $config $installPath | Out-Null
	$config.Save($configPath)
}

#update SolrSearchProvider configurations
$projectFile = Get-Item $project.FullName
$mediachaseSearchConfigPath = join-path $projectFile.Directory.FullName "Configs\Mediachase.Search.Config"
UpdateMediachaseSearchConfig -configPath $mediachaseSearchConfigPath
# SIG # Begin signature block
# MIIVlQYJKoZIhvcNAQcCoIIVhjCCFYICAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQU5QY6rhwH+x/gGMUNCOT7qOhI
# VnagghH2MIIFbzCCBFegAwIBAgIQSPyTtGBVlI02p8mKidaUFjANBgkqhkiG9w0B
# AQwFADB7MQswCQYDVQQGEwJHQjEbMBkGA1UECAwSR3JlYXRlciBNYW5jaGVzdGVy
# MRAwDgYDVQQHDAdTYWxmb3JkMRowGAYDVQQKDBFDb21vZG8gQ0EgTGltaXRlZDEh
# MB8GA1UEAwwYQUFBIENlcnRpZmljYXRlIFNlcnZpY2VzMB4XDTIxMDUyNTAwMDAw
# MFoXDTI4MTIzMTIzNTk1OVowVjELMAkGA1UEBhMCR0IxGDAWBgNVBAoTD1NlY3Rp
# Z28gTGltaXRlZDEtMCsGA1UEAxMkU2VjdGlnbyBQdWJsaWMgQ29kZSBTaWduaW5n
# IFJvb3QgUjQ2MIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAjeeUEiIE
# JHQu/xYjApKKtq42haxH1CORKz7cfeIxoFFvrISR41KKteKW3tCHYySJiv/vEpM7
# fbu2ir29BX8nm2tl06UMabG8STma8W1uquSggyfamg0rUOlLW7O4ZDakfko9qXGr
# YbNzszwLDO/bM1flvjQ345cbXf0fEj2CA3bm+z9m0pQxafptszSswXp43JJQ8mTH
# qi0Eq8Nq6uAvp6fcbtfo/9ohq0C/ue4NnsbZnpnvxt4fqQx2sycgoda6/YDnAdLv
# 64IplXCN/7sVz/7RDzaiLk8ykHRGa0c1E3cFM09jLrgt4b9lpwRrGNhx+swI8m2J
# mRCxrds+LOSqGLDGBwF1Z95t6WNjHjZ/aYm+qkU+blpfj6Fby50whjDoA7NAxg0P
# OM1nqFOI+rgwZfpvx+cdsYN0aT6sxGg7seZnM5q2COCABUhA7vaCZEao9XOwBpXy
# bGWfv1VbHJxXGsd4RnxwqpQbghesh+m2yQ6BHEDWFhcp/FycGCvqRfXvvdVnTyhe
# Be6QTHrnxvTQ/PrNPjJGEyA2igTqt6oHRpwNkzoJZplYXCmjuQymMDg80EY2NXyc
# uu7D1fkKdvp+BRtAypI16dV60bV/AK6pkKrFfwGcELEW/MxuGNxvYv6mUKe4e7id
# FT/+IAx1yCJaE5UZkADpGtXChvHjjuxf9OUCAwEAAaOCARIwggEOMB8GA1UdIwQY
# MBaAFKARCiM+lvEH7OKvKe+CpX/QMKS0MB0GA1UdDgQWBBQy65Ka/zWWSC8oQEJw
# IDaRXBeF5jAOBgNVHQ8BAf8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB/zATBgNVHSUE
# DDAKBggrBgEFBQcDAzAbBgNVHSAEFDASMAYGBFUdIAAwCAYGZ4EMAQQBMEMGA1Ud
# HwQ8MDowOKA2oDSGMmh0dHA6Ly9jcmwuY29tb2RvY2EuY29tL0FBQUNlcnRpZmlj
# YXRlU2VydmljZXMuY3JsMDQGCCsGAQUFBwEBBCgwJjAkBggrBgEFBQcwAYYYaHR0
# cDovL29jc3AuY29tb2RvY2EuY29tMA0GCSqGSIb3DQEBDAUAA4IBAQASv6Hvi3Sa
# mES4aUa1qyQKDKSKZ7g6gb9Fin1SB6iNH04hhTmja14tIIa/ELiueTtTzbT72ES+
# BtlcY2fUQBaHRIZyKtYyFfUSg8L54V0RQGf2QidyxSPiAjgaTCDi2wH3zUZPJqJ8
# ZsBRNraJAlTH/Fj7bADu/pimLpWhDFMpH2/YGaZPnvesCepdgsaLr4CnvYFIUoQx
# 2jLsFeSmTD1sOXPUC4U5IOCFGmjhp0g4qdE2JXfBjRkWxYhMZn0vY86Y6GnfrDyo
# XZ3JHFuu2PMvdM+4fvbXg50RlmKarkUT2n/cR/vfw1Kf5gZV6Z2M8jpiUbzsJA8p
# 1FiAhORFe1rYMIIGGjCCBAKgAwIBAgIQYh1tDFIBnjuQeRUgiSEcCjANBgkqhkiG
# 9w0BAQwFADBWMQswCQYDVQQGEwJHQjEYMBYGA1UEChMPU2VjdGlnbyBMaW1pdGVk
# MS0wKwYDVQQDEyRTZWN0aWdvIFB1YmxpYyBDb2RlIFNpZ25pbmcgUm9vdCBSNDYw
# HhcNMjEwMzIyMDAwMDAwWhcNMzYwMzIxMjM1OTU5WjBUMQswCQYDVQQGEwJHQjEY
# MBYGA1UEChMPU2VjdGlnbyBMaW1pdGVkMSswKQYDVQQDEyJTZWN0aWdvIFB1Ymxp
# YyBDb2RlIFNpZ25pbmcgQ0EgUjM2MIIBojANBgkqhkiG9w0BAQEFAAOCAY8AMIIB
# igKCAYEAmyudU/o1P45gBkNqwM/1f/bIU1MYyM7TbH78WAeVF3llMwsRHgBGRmxD
# eEDIArCS2VCoVk4Y/8j6stIkmYV5Gej4NgNjVQ4BYoDjGMwdjioXan1hlaGFt4Wk
# 9vT0k2oWJMJjL9G//N523hAm4jF4UjrW2pvv9+hdPX8tbbAfI3v0VdJiJPFy/7Xw
# iunD7mBxNtecM6ytIdUlh08T2z7mJEXZD9OWcJkZk5wDuf2q52PN43jc4T9OkoXZ
# 0arWZVeffvMr/iiIROSCzKoDmWABDRzV/UiQ5vqsaeFaqQdzFf4ed8peNWh1OaZX
# nYvZQgWx/SXiJDRSAolRzZEZquE6cbcH747FHncs/Kzcn0Ccv2jrOW+LPmnOyB+t
# AfiWu01TPhCr9VrkxsHC5qFNxaThTG5j4/Kc+ODD2dX/fmBECELcvzUHf9shoFvr
# n35XGf2RPaNTO2uSZ6n9otv7jElspkfK9qEATHZcodp+R4q2OIypxR//YEb3fkDn
# 3UayWW9bAgMBAAGjggFkMIIBYDAfBgNVHSMEGDAWgBQy65Ka/zWWSC8oQEJwIDaR
# XBeF5jAdBgNVHQ4EFgQUDyrLIIcouOxvSK4rVKYpqhekzQwwDgYDVR0PAQH/BAQD
# AgGGMBIGA1UdEwEB/wQIMAYBAf8CAQAwEwYDVR0lBAwwCgYIKwYBBQUHAwMwGwYD
# VR0gBBQwEjAGBgRVHSAAMAgGBmeBDAEEATBLBgNVHR8ERDBCMECgPqA8hjpodHRw
# Oi8vY3JsLnNlY3RpZ28uY29tL1NlY3RpZ29QdWJsaWNDb2RlU2lnbmluZ1Jvb3RS
# NDYuY3JsMHsGCCsGAQUFBwEBBG8wbTBGBggrBgEFBQcwAoY6aHR0cDovL2NydC5z
# ZWN0aWdvLmNvbS9TZWN0aWdvUHVibGljQ29kZVNpZ25pbmdSb290UjQ2LnA3YzAj
# BggrBgEFBQcwAYYXaHR0cDovL29jc3Auc2VjdGlnby5jb20wDQYJKoZIhvcNAQEM
# BQADggIBAAb/guF3YzZue6EVIJsT/wT+mHVEYcNWlXHRkT+FoetAQLHI1uBy/YXK
# ZDk8+Y1LoNqHrp22AKMGxQtgCivnDHFyAQ9GXTmlk7MjcgQbDCx6mn7yIawsppWk
# vfPkKaAQsiqaT9DnMWBHVNIabGqgQSGTrQWo43MOfsPynhbz2Hyxf5XWKZpRvr3d
# MapandPfYgoZ8iDL2OR3sYztgJrbG6VZ9DoTXFm1g0Rf97Aaen1l4c+w3DC+IkwF
# kvjFV3jS49ZSc4lShKK6BrPTJYs4NG1DGzmpToTnwoqZ8fAmi2XlZnuchC4NPSZa
# PATHvNIzt+z1PHo35D/f7j2pO1S8BCysQDHCbM5Mnomnq5aYcKCsdbh0czchOm8b
# kinLrYrKpii+Tk7pwL7TjRKLXkomm5D1Umds++pip8wH2cQpf93at3VDcOK4N7Ew
# oIJB0kak6pSzEu4I64U6gZs7tS/dGNSljf2OSSnRr7KWzq03zl8l75jy+hOds9TW
# SenLbjBQUGR96cFr6lEUfAIEHVC1L68Y1GGxx4/eRI82ut83axHMViw1+sVpbPxg
# 51Tbnio1lB93079WPFnYaOvfGAA0e0zcfF/M9gXr+korwQTh2Prqooq2bYNMvUoU
# KD85gnJ+t0smrWrb8dee2CvYZXD5laGtaAxOfy/VKNmwuWuAh9kcMIIGYTCCBMmg
# AwIBAgIQXAGgVVp6Ap+6PaMsqZRj/DANBgkqhkiG9w0BAQwFADBUMQswCQYDVQQG
# EwJHQjEYMBYGA1UEChMPU2VjdGlnbyBMaW1pdGVkMSswKQYDVQQDEyJTZWN0aWdv
# IFB1YmxpYyBDb2RlIFNpZ25pbmcgQ0EgUjM2MB4XDTIyMDUxODAwMDAwMFoXDTI1
# MDUxNzIzNTk1OVowVTELMAkGA1UEBhMCU0UxGDAWBgNVBAgMD1N0b2NraG9sbXMg
# bMOkbjEVMBMGA1UECgwMRXBpc2VydmVyIEFCMRUwEwYDVQQDDAxFcGlzZXJ2ZXIg
# QUIwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCojYASngXIv2En9aBr
# hDwGjFDZzyFjwd2bskGnQzn2nWtAmUvwF5c6SlI6pMk4I7nUkdKrZ3qMGOxyr0g2
# Ht2R4jW3hnbGwEbclauNF/pqcXfDy+eTcANBe4HVdMTd/jOcvAg5Zhszjk0KNRl3
# XxUORj7eWgfX96ndsJNn/sD07GkS8ZFHXTEyoOW26/eJ0qOGRWlMNrIc3JnoGHjS
# RrYJmjsjgoHDOVmZrJRfUOU7xWuexNaHWxDHt4rpGfjkaazw7NMFZxT4+X9R8B/k
# 5qFaPcDr/eZnIJVlNSdz9UQxF2J/LEbS7a207Tseq5Tx4kWkPYXkZnJB8DHOz3OZ
# ejIlNFSvA2m16JxEn++LazZZy+G0gkLYVNVbX1dgskVWJrqS4WVGLjAczqeBtVQ8
# KxsUEfyNM9t010s/b9Ac3CSrCHVOxdWSbAno4SezYI4a2gJMZOEZKzcZ0xH237bi
# EQFufY/iE63nFqtPgFxsivyUazs0I1Tic2qu/6q4drabD/vEBjU7RM7BsOUvqJLY
# 53k3MyURJLEgTFy1NtB4MUa7CTiIVLHlPwW9/KF6VzGzXABLnKhekYF7eVRJvrfD
# jNP22WC2VVy5sOxTOoCnSGa8KDw9JLBDwW9RgbufcNY9E569s/qwq35PJiljEHMM
# 4sofFu9pY2d1iGOTJ2p4Vpg5QQIDAQABo4IBrDCCAagwHwYDVR0jBBgwFoAUDyrL
# IIcouOxvSK4rVKYpqhekzQwwHQYDVR0OBBYEFN3YgPa91L0oKYWS5rSzX36XJxrG
# MA4GA1UdDwEB/wQEAwIHgDAMBgNVHRMBAf8EAjAAMBMGA1UdJQQMMAoGCCsGAQUF
# BwMDMEoGA1UdIARDMEEwNQYMKwYBBAGyMQECAQMCMCUwIwYIKwYBBQUHAgEWF2h0
# dHBzOi8vc2VjdGlnby5jb20vQ1BTMAgGBmeBDAEEATBJBgNVHR8EQjBAMD6gPKA6
# hjhodHRwOi8vY3JsLnNlY3RpZ28uY29tL1NlY3RpZ29QdWJsaWNDb2RlU2lnbmlu
# Z0NBUjM2LmNybDB5BggrBgEFBQcBAQRtMGswRAYIKwYBBQUHMAKGOGh0dHA6Ly9j
# cnQuc2VjdGlnby5jb20vU2VjdGlnb1B1YmxpY0NvZGVTaWduaW5nQ0FSMzYuY3J0
# MCMGCCsGAQUFBzABhhdodHRwOi8vb2NzcC5zZWN0aWdvLmNvbTAhBgNVHREEGjAY
# gRZzdXBwb3J0QG9wdGltaXplbHkuY29tMA0GCSqGSIb3DQEBDAUAA4IBgQBImWGe
# xutmpiCGn//9K7MHWrZCHZsoKj62hZGb8jnqIizod7LculgKVTJIX7wLU0IhJnTt
# EPR0GCstRkBA7U65D8fbmT9RhqnDHA/+rAuU3NulNbmOGAM5tLL7yvbo3+8EcWjv
# acu8eOXeaG3O/CGGh98ph94akvkjg/YlUYuKE8jYUtc07gVS6GLzJx5x5nz4aBu2
# 0C9gcG5D5XM/IWQWrQhoCbvRxpUoJpOe+GSjA38lCM2f+Ch5JUmNfA2bVn2yrElT
# pGkydHtL3Wdkfr86uwSAWUu2CkaxYNHBmQ0u9wmQhPoQQu8XLZlp6a7bR7hSyPnW
# +BF8vwOaeMP89n+v1h5PaDWHFtPLLUklqlSDbicz3QhUtrIjCNRtXdNnPTR7CwCt
# p3uzdqpxIWbuZ0B8pPEdrTfF45TyHydkjyVkeU8zmwS7BangrG2Ae2/hn67CvROI
# 7btx10+CA2kj8UV6zla/icwrvyxcmre70goyhQQ37/8EbodVOaIiTFL5NewxggMJ
# MIIDBQIBATBoMFQxCzAJBgNVBAYTAkdCMRgwFgYDVQQKEw9TZWN0aWdvIExpbWl0
# ZWQxKzApBgNVBAMTIlNlY3RpZ28gUHVibGljIENvZGUgU2lnbmluZyBDQSBSMzYC
# EFwBoFVaegKfuj2jLKmUY/wwCQYFKw4DAhoFAKB4MBgGCisGAQQBgjcCAQwxCjAI
# oAKAAKECgAAwGQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIB
# CzEOMAwGCisGAQQBgjcCARUwIwYJKoZIhvcNAQkEMRYEFH7X23Nm06Cc5ADzp8dm
# v0uwsz0lMA0GCSqGSIb3DQEBAQUABIICAExoYf69fOoIeEGTizDvJVFLLA968iHK
# Dy9GBi5Iv68E3Vi+PEsubLIK7TvYQx4x39XX7TVQhAiEOWQDXzQ68uokpsAvvX1N
# 3M4sd8EUd8uu+Sh+3OIrWi+OFiLiggm4OfUGF2HknM55gQnl0YRZk1PhVj1S2zMs
# N3k9XAFHzU4XD62l4RkOpIp2FEjiOrHv7DfZ6c1lH2kwAs6DPmxXB/Ncl6WSHd/Z
# cVZmnN5QGMpy4Mo+4qzyvL2b5POjA9a1wRA8wTvw+BtXNGNzJR1SQRvBrURtwzKc
# vqXR6YQ0/D9oMZg+MKrg4+eOb8/b6hqGp7pLonkL6itcA5ijft5bNd/L91RrH3Sh
# 1yI8rGs9/BbiPE016jNDIaSPQlGNmzdYTWWbHoKXW2xV8dZuwQjGd2jCacu2s164
# 6EnqpXqMzxi9pK9rO/0g0VRGuE48L48GeORWmidP9oGFK2nmzeB/jtwj3prA5XV2
# QO44FBbIS8QoSM+u3cIN/xxfoZhp+4sdZZtdWM3KgxFQG9cbvhWTZ8RbUATayMS3
# GXNdNT6LQk5miLvx26ZDPoP2wmG5+ACYEUt51cNi1hjeLrbSo3JyQ1ZOAirYE1b2
# kpobyj5LcrbLRiJ4yzu2kn9GORg+zYkx1Hm7pr2mDLPyAIQw5DIZI2zg0nApsRu1
# Zhrqg2EfWGAx
# SIG # End signature block
